--- setup.py.orig	2025-01-25 08:39:20 UTC
+++ setup.py
@@ -45,10 +45,10 @@ if platformname == 'darwin':
         '-Werror-implicit-function-declaration',
         '-Wfatal-errors'
     ]
-elif platformname == 'linux':
+elif platformname == 'linux' or platformname == 'freebsd':
     libraries.append('lo')
-    include_dirs.extend(['/usr/include', '/usr/local/include'])
-    library_dirs.append("/usr/local/lib")
+    include_dirs.extend(['/usr/include', '%%PREFIX%%/include'])
+    library_dirs.append("%%PREFIX%%/lib")
     compile_args += [
         '-fno-strict-aliasing',
         '-Werror-implicit-function-declaration',



--- examples/load_dwg.py.orig	2020-01-16 22:20:43 UTC
+++ examples/load_dwg.py
@@ -1,7 +1,7 @@
 #! /usr/bin/python
 
 #import libredwg
-from libredwg import *
+from LibreDWG import *
 
 import sys
 
@@ -15,7 +15,7 @@ a.object = new_Dwg_Object_Array(1000)
 error = dwg_read_file(filename, a)
 
 if (error > 0): # critical errors
-    print "Error: ", error
+    print("Error: ", error)
     if (error > 127):
         exit()
 



--- data/db/android/create_db.py.orig	2020-10-11 20:12:08 UTC
+++ data/db/android/create_db.py
@@ -3,27 +3,27 @@ from pydict import *
 from id import *
 from valid_hanzi import *
 import sys
+from functools import cmp_to_key
 
 def get_sheng_yun(pinyin):
     if pinyin == None:
         return None, None
     if pinyin == "ng":
         return "", "en"
-    for i in xrange(2, 0, -1):
+    for i in range(2, 0, -1):
         t = pinyin[:i]
         if t in SHENGMU_DICT:
             return t, pinyin[len(t):]
     return "", pinyin
 
 def read_phrases(filename):
-    buf = file(filename).read()
-    buf = unicode(buf, "utf16")
+    buf = open(filename, encoding='utf-16').read()
     buf = buf.strip()
-    for l in buf.split(u'\n'):
-        hanzi, freq, flag, pinyin = l.split(u' ', 3)
+    for l in buf.split('\n'):
+        hanzi, freq, flag, pinyin = l.split(' ', 3)
         freq = float(freq)
         pinyin = pinyin.split()
-        if any(map(lambda c: c not in valid_hanzi, hanzi)):
+        if any([c not in valid_hanzi for c in hanzi]):
             continue
         yield hanzi, freq, pinyin
 
@@ -33,9 +33,9 @@ def create_db(filename):
     # con.execute ("PRAGMA synchronous = NORMAL;")
     # con.execute ("PRAGMA temp_store = MEMORY;")
     # con.execute ("PRAGMA default_cache_size = 5000;")
-    print "PRAGMA synchronous = NORMAL;"
-    print "PRAGMA temp_store = MEMORY;"
-    print "PRAGMA default_cache_size = 5000;"
+    print("PRAGMA synchronous = NORMAL;")
+    print("PRAGMA temp_store = MEMORY;")
+    print("PRAGMA default_cache_size = 5000;")
 
 
     sql = "CREATE TABLE py_phrase_%d (phrase TEXT, freq INTEGER, %s);"
@@ -44,12 +44,12 @@ def create_db(filename):
         for j in range(0, i + 1):
             column.append ("s%d INTEGER" % j)
             column.append ("y%d INTEGER" % j)
-        print sql % (i, ",".join(column))
+        print(sql % (i, ",".join(column)))
         # con.execute(sql % (i, column))
         # con.commit()
 
     records = list(read_phrases(filename))
-    records.sort(lambda a, b: 1 if a[1] > b[1] else -1)
+    records.sort(key=cmp_to_key(lambda a, b: 1 if a[1] > b[1] else -1))
     records_new = []
     i = 0
     max_freq = 0.0
@@ -60,7 +60,7 @@ def create_db(filename):
         records_new.append((hanzi, i, pinyin))
     records_new.reverse()
     
-    print "BEGIN;"
+    print("BEGIN;")
     insert_sql = "INSERT INTO py_phrase_%d VALUES (%s);"
     for hanzi, freq, pinyin in records_new:
         columns = []
@@ -69,12 +69,12 @@ def create_db(filename):
             s, y = pinyin_id[s], pinyin_id[y]
             columns.append(s)
             columns.append(y)
-        values = "'%s', %d, %s" % (hanzi.encode("utf8"), freq, ",".join(map(str,columns)))
+        values = "'%s', %d, %s" % (hanzi, freq, ",".join(map(str,columns)))
             
         sql = insert_sql % (len(hanzi) - 1, values)
-        print sql
-    print "COMMIT;"
-    print "VACUUM;"
+        print(sql)
+    print("COMMIT;")
+    print("VACUUM;")
 
 def main():
     create_db(sys.argv[1])



--- setup.py.orig	2015-11-02 21:50:21 UTC
+++ setup.py
@@ -45,7 +45,7 @@ setup(
 print(("%s version %s" % (PkgName, Version.__version__)))
 
 setup(
-    name = PkgName,
+    name = PkgName.lower(),
     version = Version.__version__,
     description = "Collection of utilities including general algorithms, astronomical transformations and Tkinter widgets",
     long_description = long_description,



--- setup.py.orig	2019-11-29 03:48:07 UTC
+++ setup.py
@@ -18,6 +18,9 @@ if sys.platform == 'darwin':
 elif sys.platform.startswith("linux"):
     platform_sources = ['c_src/simpleaudio_alsa.c', 'c_src/posix_mutex.c']
     platform_libs = ['asound']
+elif sys.platform.startswith("freebsd"):
+    platform_sources = ['c_src/simpleaudio_alsa.c', 'c_src/posix_mutex.c'] # it doesn't appear to be any other choice than ALSA
+    platform_libs = ['asound']
 elif sys.platform == 'win32':
     platform_sources = ['c_src/simpleaudio_win.c', 'c_src/windows_mutex.c']
     platform_libs = ['Winmm', 'User32']
